@@ -136,6 +136,7 @@ void MainWindow::init()
     connect(m_ui->actionNextPage, SIGNAL(triggered()), this, SLOT(nextPage()));
     connect(m_ui->actionPrevPage, SIGNAL(triggered()), this, SLOT(prevPage()));
 
+    connect(m_ui->actionPanningOn, SIGNAL(triggered()), this, SLOT(toggleSelection()));
     m_ui->actionCopy->setEnabled(false);
     connect(m_ui->actionCopy, SIGNAL(triggered()), this, SLOT(copy()));
 
@@ -530,6 +531,9 @@ void MainWindow::zoomIn()
     if (!m_view || !m_ui)
         return;
     KoZoomAction *zAction = m_view->zoomController()->zoomAction();
+    if (zAction->effectiveZoom() * 100 > 95) {
+        return;
+    }
     zAction->zoomIn();
     int factor = zAction->effectiveZoom() * 100;
     m_ui->actionZoomLevel->setText(i18n("%1 %", QString::number(factor)));
@@ -558,6 +562,10 @@ void MainWindow::zoomToPage()
     if (!m_view || !m_ui)
         return;
     m_view->zoomController()->setZoomMode(KoZoomMode::ZOOM_PAGE);
+
+    KoZoomAction *zAction = m_view->zoomController()->zoomAction();
+    int factor = zAction->effectiveZoom() * 100;
+    m_ui->actionZoomLevel->setText(i18n("%1 %", QString::number(factor)));
 }
 
 void MainWindow::zoomToPageWidth()
@@ -565,6 +573,10 @@ void MainWindow::zoomToPageWidth()
     if (!m_view || !m_ui)
         return;
     m_view->zoomController()->setZoomMode(KoZoomMode::ZOOM_WIDTH);
+
+    KoZoomAction *zAction = m_view->zoomController()->zoomAction();
+    int factor = zAction->effectiveZoom() * 100;
+    m_ui->actionZoomLevel->setText(i18n("%1 %", QString::number(factor)));
 }
 
 void MainWindow::prevPage()
